'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _defineProperty2 = require('babel-runtime/helpers/defineProperty');

var _defineProperty3 = _interopRequireDefault(_defineProperty2);

exports.default = create;

var _react = require('react');

var _constants = require('../util/constants');

var _createWrapperComponent = require('../util/create-wrapper-component');

var _createWrapperComponent2 = _interopRequireDefault(_createWrapperComponent);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function create(styles) {
  var ShowForScreenSize = (0, _createWrapperComponent2.default)({
    displayName: 'ShowForScreenSize',
    propTypes: {
      screenSize: _react.PropTypes.oneOf(_constants.SCREEN_SIZES).isRequired
    },
    mapPropsToClassNames: function mapPropsToClassNames(_ref) {
      var screenSize = _ref.screenSize;
      return (0, _defineProperty3.default)({}, styles['show-for-' + screenSize], _constants.LARGER_SCREEN_SIZES.includes(screenSize));
    }
  });

  var ShowOnlyForScreenSize = (0, _createWrapperComponent2.default)({
    displayName: 'ShowOnlyForScreenSize',
    propTypes: {
      screenSize: _react.PropTypes.oneOf(_constants.SCREEN_SIZES).isRequired
    },
    mapPropsToClassNames: function mapPropsToClassNames(_ref3) {
      var screenSize = _ref3.screenSize;
      return (0, _defineProperty3.default)({}, styles['show-for-' + screenSize + '-only'], _constants.SCREEN_SIZES.includes(screenSize));
    }
  });

  var HideForScreenSize = (0, _createWrapperComponent2.default)({
    displayName: 'HideForScreenSize',
    propTypes: {
      screenSize: _react.PropTypes.oneOf(_constants.SCREEN_SIZES).isRequired
    },
    mapPropsToClassNames: function mapPropsToClassNames(_ref5) {
      var _ref6;

      var screenSize = _ref5.screenSize;
      return _ref6 = {}, (0, _defineProperty3.default)(_ref6, styles.hide, !_constants.LARGER_SCREEN_SIZES.includes(screenSize) && _constants.SCREEN_SIZES.includes(screenSize)), (0, _defineProperty3.default)(_ref6, styles['hide-for-' + screenSize], _constants.LARGER_SCREEN_SIZES.includes(screenSize)), _ref6;
    }
  });

  var HideOnlyForScreenSize = (0, _createWrapperComponent2.default)({
    displayName: 'HideOnlyForScreenSize',
    propTypes: {
      screenSize: _react.PropTypes.oneOf(_constants.SCREEN_SIZES).isRequired
    },
    mapPropsToClassNames: function mapPropsToClassNames(_ref7) {
      var screenSize = _ref7.screenSize;
      return (0, _defineProperty3.default)({}, styles['hide-for-' + screenSize + '-only'], _constants.SCREEN_SIZES.includes(screenSize));
    }
  });

  var Hide = (0, _createWrapperComponent2.default)({
    displayName: 'Hide',
    mapPropsToClassNames: function mapPropsToClassNames() {
      return (0, _defineProperty3.default)({}, styles.hide, true);
    }
  });

  var Invisible = (0, _createWrapperComponent2.default)({
    displayName: 'Invisible',
    mapPropsToClassNames: function mapPropsToClassNames() {
      return (0, _defineProperty3.default)({}, styles.invisible, true);
    }
  });

  var ShowForScreenOrientation = (0, _createWrapperComponent2.default)({
    displayName: 'ShowForScreenOrientation',
    propTypes: {
      screenOrientation: _react.PropTypes.oneOf(_constants.SCREEN_ORIENTATIONS).isRequired
    },
    mapPropsToClassNames: function mapPropsToClassNames(_ref11) {
      var screenOrientation = _ref11.screenOrientation;
      return (0, _defineProperty3.default)({}, styles['show-for-' + screenOrientation], _constants.SCREEN_ORIENTATIONS.includes(screenOrientation));
    }
  });

  var HideForScreenOrientation = (0, _createWrapperComponent2.default)({
    displayName: 'HideForScreenOrientation',
    propTypes: {
      screenOrientation: _react.PropTypes.oneOf(_constants.SCREEN_ORIENTATIONS).isRequired
    },
    mapPropsToClassNames: function mapPropsToClassNames(_ref13) {
      var screenOrientation = _ref13.screenOrientation;
      return (0, _defineProperty3.default)({}, styles['hide-for-' + screenOrientation], _constants.SCREEN_ORIENTATIONS.includes(screenOrientation));
    }
  });

  var ShowOnlyForScreenReader = (0, _createWrapperComponent2.default)({
    displayName: 'ShowOnlyForScreenReader',
    mapPropsToClassNames: function mapPropsToClassNames() {
      return (0, _defineProperty3.default)({}, styles['show-for-sr'], true);
    }
  });

  var HideOnlyForScreenReader = (0, _createWrapperComponent2.default)({
    displayName: 'HideOnlyForScreenReader',
    mapPropsToProps: function mapPropsToProps(props) {
      return (0, _extends3.default)({}, props, {
        'aria-hidden': true
      });
    }
  });

  var ShowOnlyOnFocus = (0, _createWrapperComponent2.default)({
    displayName: 'ShowOnlyOnFocus',
    mapPropsToClassNames: function mapPropsToClassNames() {
      return (0, _defineProperty3.default)({}, styles['show-on-focus'], true);
    }
  });

  return {
    ShowForScreenSize: ShowForScreenSize,
    ShowOnlyForScreenSize: ShowOnlyForScreenSize,
    HideForScreenSize: HideForScreenSize,
    HideOnlyForScreenSize: HideOnlyForScreenSize,
    Hide: Hide,
    Invisible: Invisible,
    ShowForScreenOrientation: ShowForScreenOrientation,
    HideForScreenOrientation: HideForScreenOrientation,
    ShowOnlyForScreenReader: ShowOnlyForScreenReader,
    HideOnlyForScreenReader: HideOnlyForScreenReader,
    ShowOnlyOnFocus: ShowOnlyOnFocus
  };
}